Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(261)

Unified Diff: content/browser/gpu/compositor_util.h

Issue 2020243004: content: Rename num raster threads -> num worker threads. Base URL: https://chromium.googlesource.com/chromium/src.git@categorized_worker_pool_3
Patch Set: build break Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/gpu/compositor_util.h
diff --git a/content/browser/gpu/compositor_util.h b/content/browser/gpu/compositor_util.h
index 61d597ac6d507f0cb3c6eeae3a482fc5a34a6d6e..1710b015aa60f74361947406efde9b429b24f4a3 100644
--- a/content/browser/gpu/compositor_util.h
+++ b/content/browser/gpu/compositor_util.h
@@ -36,8 +36,8 @@ CONTENT_EXPORT int GpuRasterizationMSAASampleCount();
// Returns true if force-gpu-rasterization is on (via flags) for the renderer.
CONTENT_EXPORT bool IsForceGpuRasterizationEnabled();
-// Returns the number of raster threads to use for compositing.
-CONTENT_EXPORT int NumberOfRendererRasterThreads();
+// Returns the number of categorized worker threads to use for compositing.
+CONTENT_EXPORT int NumberOfRendererCategorizedWorkerThreads();
// Returns true if main thread can be pipelined with activation.
CONTENT_EXPORT bool IsMainFrameBeforeActivationEnabled();

Powered by Google App Engine
This is Rietveld 408576698